@@ -1,3 +1,8 @@
+__version__ = "0.0.2"
+
+import warnings
+warnings.filterwarnings("ignore")
+
 from . import component
 from . import data_handler
 from . import distribution
@@ -5,4 +10,6 @@ from . import evaluation
 from . import visualization
 from . import utils
 from . import model
-from . import framework
\ No newline at end of file
+from . import framework
+
+
